==> client-core-1.4.0.tgz: package/src/admin/components/Setting/ClientTheme/ThemeSelectionArea.tsx <==
/*
CPAL-1.0 License

The contents of this file are subject to the Common Public Attribution License
Version 1.0. (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
https://github.com/EtherealEngine/etherealengine/blob/dev/LICENSE.
The License is based on the Mozilla Public License Version 1.1, but Sections 14
and 15 have been added to cover use of software over a computer network and 
provide for limited attribution for the Original Developer. In addition, 
Exhibit A has been modified to be consistent with Exhibit B.

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the
specific language governing rights and limitations under the License.

The Original Code is Ethereal Engine.

The Original Developer is the Initial Developer. The Initial Developer of the
Original Code is the Ethereal Engine team.

All portions of the code written by the Ethereal Engine team are Copyright © 2021-2023 
Ethereal Engine. All Rights Reserved.
*/

import React from 'react'
import { useTranslation } from 'react-i18next'

import InputSelect, { InputMenuItem } from '@etherealengine/client-core/src/common/components/InputSelect'
import capitalizeFirstLetter from '@etherealengine/common/src/utils/capitalizeFirstLetter'
import Grid from '@etherealengine/ui/src/primitives/mui/Grid'
import Typography from '@etherealengine/ui/src/primitives/mui/Typography'

import styles from '../../../styles/settings.module.scss'

interface ThemeSelectionAreaProps {
  themeModes: Record<string, string>
  colorModes: string[]
  onChangeThemeMode: Function
}

const ThemeSelectionArea = ({ themeModes, colorModes, onChangeThemeMode }: ThemeSelectionAreaProps) => {
  const { t } = useTranslation()

  const colorModesMenu: InputMenuItem[] = colorModes.map((el) => {
    return {
      label: capitalizeFirstLetter(el),
      value: el
    }
  })

  return (
    <>
      <Typography component="h1" className={styles.settingsHeading}>
        {t('admin:components.setting.defaultThemes')}
      </Typography>

      <Grid container spacing={4} sx={{ mb: 3 }}>
        {Object.keys(themeModes).map((mode, index) => (
          <Grid key={index} item xs={12} sm={6} md={4}>
            <InputSelect
              name={mode}
              label={`${t(`admin:components.setting.${mode}`)} ${t('admin:components.setting.theme')}`}
              value={themeModes[mode]}
              menu={colorModesMenu}
              onChange={(e) => onChangeThemeMode(e)}
            />
          </Grid>
        ))}
      </Grid>
    </>
  )
}

export default ThemeSelectionArea

==> client-core-1.5.0.tgz: package/src/admin/components/Setting/ClientTheme/ThemeSelectionArea.tsx <==
/*
CPAL-1.0 License

The contents of this file are subject to the Common Public Attribution License
Version 1.0. (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
https://github.com/EtherealEngine/etherealengine/blob/dev/LICENSE.
The License is based on the Mozilla Public License Version 1.1, but Sections 14
and 15 have been added to cover use of software over a computer network and 
provide for limited attribution for the Original Developer. In addition, 
Exhibit A has been modified to be consistent with Exhibit B.

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the
specific language governing rights and limitations under the License.

The Original Code is Ethereal Engine.

The Original Developer is the Initial Developer. The Initial Developer of the
Original Code is the Ethereal Engine team.

All portions of the code written by the Ethereal Engine team are Copyright © 2021-2023 
Ethereal Engine. All Rights Reserved.
*/

import React from 'react'
import { useTranslation } from 'react-i18next'

import InputSelect, { InputMenuItem } from '@etherealengine/client-core/src/common/components/InputSelect'
import capitalizeFirstLetter from '@etherealengine/common/src/utils/capitalizeFirstLetter'
import Grid from '@etherealengine/ui/src/primitives/mui/Grid'
import Typography from '@etherealengine/ui/src/primitives/mui/Typography'

import styles from '../../../styles/settings.module.scss'

interface ThemeSelectionAreaProps {
  themeModes: Record<string, string>
  colorModes: string[]
  onChangeThemeMode: (e: React.ChangeEvent<{ value: string }>) => void
}

const ThemeSelectionArea = ({ themeModes, colorModes, onChangeThemeMode }: ThemeSelectionAreaProps) => {
  const { t } = useTranslation()

  const colorModesMenu: InputMenuItem[] = colorModes.map((el) => {
    return {
      label: capitalizeFirstLetter(el),
      value: el
    }
  })

  return (
    <>
      <Typography component="h1" className={styles.settingsHeading}>
        {t('admin:components.setting.defaultThemes')}
      </Typography>

      <Grid container spacing={4} sx={{ mb: 3 }}>
        {Object.keys(themeModes).map((mode, index) => (
          <Grid key={index} item xs={12} sm={6} md={4}>
            <InputSelect
              name={mode}
              label={`${t(`admin:components.setting.${mode}`)} ${t('admin:components.setting.theme')}`}
              value={themeModes[mode]}
              menu={colorModesMenu}
              onChange={(e) => onChangeThemeMode(e)}
            />
          </Grid>
        ))}
      </Grid>
    </>
  )
}

export default ThemeSelectionArea
